# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

_Public Classes_

* [`sensu`](#sensu): Base Sensu class
* [`sensu::agent`](#sensuagent): Manage Sensu agent
* [`sensu::backend`](#sensubackend): Manage Sensu backend
* [`sensu::plugins`](#sensuplugins): Manage Sensu plugins

_Private Classes_

* `sensu::backend::datastore::postgresql`: Manage Sensu backend PostgreSQL datastore
* `sensu::backend::default_resources`: Default sensu resources
* `sensu::backend::resources`: Define sensu resources
* `sensu::backend::tessen`: Manage tessen phone home
* `sensu::repo`: Private class to manage sensu repository resources
* `sensu::repo::community`: Private class to manage sensu community repository resources
* `sensu::ssl`: Private class to manage sensu SSL resources

**Resource types**

* [`sensu_ad_auth`](#sensu_ad_auth): Manages Sensu Active Directory auth. Requires valid enterprise license.
* [`sensu_api_validator`](#sensu_api_validator): Verify that a connection can be successfully established between a node and the sensu-backend server.  Its primary use is as a precondition t
* [`sensu_asset`](#sensu_asset): Manages Sensu assets
* [`sensu_bonsai_asset`](#sensu_bonsai_asset): Manages Sensu Bonsai assets
* [`sensu_check`](#sensu_check): Manages Sensu checks
* [`sensu_cluster_member`](#sensu_cluster_member): Manages Sensu cluster members
* [`sensu_cluster_role`](#sensu_cluster_role): Manages Sensu cluster roles
* [`sensu_cluster_role_binding`](#sensu_cluster_role_binding): Manages Sensu cluster role bindings
* [`sensu_config`](#sensu_config): Manages Sensu configs
* [`sensu_configure`](#sensu_configure): Manages `sensuctl configure`. This is a private type not intended to be used directly.
* [`sensu_entity`](#sensu_entity): Manages Sensu entities
* [`sensu_etcd_replicator`](#sensu_etcd_replicator): Manages Sensu etcd replicators
* [`sensu_event`](#sensu_event): Manages Sensu events
* [`sensu_filter`](#sensu_filter): Manages Sensu filters
* [`sensu_handler`](#sensu_handler): Manages Sensu handlers
* [`sensu_hook`](#sensu_hook): Manages Sensu hooks
* [`sensu_ldap_auth`](#sensu_ldap_auth): Manages Sensu LDAP auth. Requires valid enterprise license.
* [`sensu_mutator`](#sensu_mutator): Manages Sensu mutators
* [`sensu_namespace`](#sensu_namespace): Manages Sensu namespaces
* [`sensu_oidc_auth`](#sensu_oidc_auth): Manages Sensu OIDC auth. Requires valid enterprise license.
* [`sensu_plugin`](#sensu_plugin): Manages Sensu plugins
* [`sensu_postgres_config`](#sensu_postgres_config): Manages Sensu postgres config
* [`sensu_resources`](#sensu_resources): Metatype for sensu resources
* [`sensu_role`](#sensu_role): Manages Sensu roles
* [`sensu_role_binding`](#sensu_role_binding): Manages Sensu role bindings
* [`sensu_silenced`](#sensu_silenced): Manages Sensu silencing
* [`sensu_user`](#sensu_user): Manages Sensu users
* [`sensuctl_config`](#sensuctl_config): Abstract type to configure other types

**Data types**

* [`Sensu::Backend_URL`](#sensubackend_url): Sensu Backend URL's require protocol of ws:// or wss://. A port is also required. There is logic in sensu::agent class to add the protocol so

**Tasks**

* [`agent_event`](#agent_event): Create a Sensu Go agent event via the agent API
* [`apikey`](#apikey): Manage Sensu Go API keys
* [`assets_outdated`](#assets_outdated): Retreive outdated Sensu Go assets
* [`check_execute`](#check_execute): Execute a Sensu Go check
* [`event`](#event): Manage Sensu Go events
* [`install_agent`](#install_agent): Install Sensu Go agent
* [`install_agent_linux`](#install_agent_linux): Install Sensu Go agent on Linux
* [`install_agent_windows`](#install_agent_windows): Install Sensu Go agent on Windows
* [`silenced`](#silenced): Manage Sensu Go silencings

## Classes

### sensu

This is the main Sensu class

#### Parameters

The following parameters are available in the `sensu` class.

##### `version`

Data type: `String`

Version of Sensu to install.  Defaults to `installed` to support
Windows MSI packaging and to avoid surprising upgrades.

Default value: 'installed'

##### `etc_dir`

Data type: `Stdlib::Absolutepath`

Absolute path to the Sensu etc directory.

Default value: '/etc/sensu'

##### `ssl_dir`

Data type: `Stdlib::Absolutepath`

Absolute path to the Sensu ssl directory.

Default value: '/etc/sensu/ssl'

##### `user`

Data type: `String`

User used by sensu services

Default value: 'sensu'

##### `group`

Data type: `String`

User group used by sensu services

Default value: 'sensu'

##### `etc_dir_purge`

Data type: `Boolean`

Boolean to determine if the etc_dir should be purged
such that only Puppet managed files are present.

Default value: `true`

##### `ssl_dir_purge`

Data type: `Boolean`

Boolean to determine if the ssl_dir should be purged
such that only Puppet managed files are present.

Default value: `true`

##### `manage_repo`

Data type: `Boolean`

Boolean to determine if software repository for Sensu
should be managed.

Default value: `true`

##### `use_ssl`

Data type: `Boolean`

Sensu backend service uses SSL

Default value: `true`

##### `ssl_ca_source`

Data type: `Optional[String]`

Source of SSL CA used by sensu services

Default value: $facts['puppet_localcacert']

### sensu::agent

Class to manage the Sensu agent.

#### Examples

##### 

```puppet
class { 'sensu::agent':
  backends    => ['sensu-backend.example.com:8081'],
  config_hash => {
    'subscriptions => ['linux', 'apache-servers'],
  },
}
```

#### Parameters

The following parameters are available in the `sensu::agent` class.

##### `version`

Data type: `Optional[String]`

Version of sensu agent to install.  Defaults to `installed` to support
Windows MSI packaging and to avoid surprising upgrades.

Default value: `undef`

##### `package_source`

Data type: `Optional[String[1]]`

Source of package for installing Windows.
Paths with http:// or https:// will be downloaded
Paths with puppet:// or absolute filesystem paths will also be installed.

Default value: `undef`

##### `package_download_path`

Data type: `Optional[Stdlib::Absolutepath]`

Where to download the MSI for Windows. Defaults to `C:\`.
This parameter only used when `package_source` is an URL or when it's a puppet source (`puppet://`).

Default value: `undef`

##### `package_name`

Data type: `String`

Name of Sensu agent package.

Default value: 'sensu-go-agent'

##### `service_env_vars_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to the agent service ENV variables file.
Debian based default: `/etc/default/sensu-agent`
RedHat based default: `/etc/sysconfig/sensu-agent`

Default value: `undef`

##### `service_env_vars`

Data type: `Hash`

Hash of environment variables loaded by sensu-agent service

Default value: {}

##### `service_name`

Data type: `String`

Name of the Sensu agent service.

Default value: 'sensu-agent'

##### `service_ensure`

Data type: `String`

Sensu agent service ensure value.

Default value: 'running'

##### `service_enable`

Data type: `Boolean`

Sensu agent service enable value.

Default value: `true`

##### `config_hash`

Data type: `Hash`

Sensu agent configuration hash used to define agent.yml.

Default value: {}

##### `backends`

Data type: `Array[Sensu::Backend_URL]`

Array of sensu backends to pass to `backend-url` config option.
The protocol prefix of `ws://` or `wss://` are optional and will be determined
based on `sensu::use_ssl` parameter by default.
Passing `backend-url` as part of `config_hash` takes precedence.

Default value: ['localhost:8081']

##### `show_diff`

Data type: `Boolean`

Sets show_diff parameter for agent.yml configuration file

Default value: `true`

##### `log_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to agent log file, only for Windows.
Defaults to `C:\ProgramData\sensu\log\sensu-agent.log`

Default value: `undef`

### sensu::backend

Class to manage the Sensu backend.

#### Examples

##### 

```puppet
class { 'sensu::backend':
  password => 'secret',
}
```

#### Parameters

The following parameters are available in the `sensu::backend` class.

##### `version`

Data type: `Optional[String]`

Version of sensu backend to install.  Defaults to `installed` to support
Windows MSI packaging and to avoid surprising upgrades.

Default value: `undef`

##### `package_name`

Data type: `String`

Name of Sensu backend package.

Default value: 'sensu-go-backend'

##### `cli_package_name`

Data type: `String`

Name of Sensu CLI package.

Default value: 'sensu-go-cli'

##### `service_env_vars_file`

Data type: `Optional[Stdlib::Absolutepath]`

Path to the backend service ENV variables file.
Debian based default: `/etc/default/sensu-backend`
RedHat based default: `/etc/sysconfig/sensu-backend`

Default value: `undef`

##### `service_env_vars`

Data type: `Hash`

Hash of environment variables loaded by sensu-backend service

Default value: {}

##### `service_name`

Data type: `String`

Name of the Sensu backend service.

Default value: 'sensu-backend'

##### `service_ensure`

Data type: `String`

Sensu backend service ensure value.

Default value: 'running'

##### `service_enable`

Data type: `Boolean`

Sensu backend service enable value.

Default value: `true`

##### `state_dir`

Data type: `Stdlib::Absolutepath`

Sensu backend state directory path.

Default value: '/var/lib/sensu/sensu-backend'

##### `config_hash`

Data type: `Hash`

Sensu backend configuration hash used to define backend.yml.

Default value: {}

##### `url_host`

Data type: `String`

Sensu backend host used to configure sensuctl and verify API access.

Default value: $trusted['certname']

##### `url_port`

Data type: `Stdlib::Port`

Sensu backend port used to configure sensuctl and verify API access.

Default value: 8080

##### `ssl_cert_source`

Data type: `Optional[String]`

The SSL certificate source

Default value: $facts['puppet_hostcert']

##### `ssl_key_source`

Data type: `Optional[String]`

The SSL private key source

Default value: $facts['puppet_hostprivkey']

##### `password`

Data type: `String`

Sensu backend admin password used to confiure sensuctl.

Default value: 'P@ssw0rd!'

##### `old_password`

Data type: `Optional[String]`

Sensu backend admin old password needed when changing password.

Default value: `undef`

##### `agent_password`

Data type: `String`

The sensu agent password

Default value: 'P@ssw0rd!'

##### `agent_old_password`

Data type: `Optional[String]`

The sensu agent old password needed when changing agent_password

Default value: `undef`

##### `include_default_resources`

Data type: `Boolean`

Sets if default sensu resources should be included

Default value: `true`

##### `show_diff`

Data type: `Boolean`

Sets show_diff parameter for backend.yml configuration file

Default value: `true`

##### `license_source`

Data type: `Optional[String]`

The source of sensu-go enterprise license.
Supports any valid Puppet File sources such as absolute paths or puppet:///
Do not define with license_content

Default value: `undef`

##### `license_content`

Data type: `Optional[String]`

The content of sensu-go enterprise license
Do not define with license_source

Default value: `undef`

##### `manage_tessen`

Data type: `Boolean`

Boolean that determines if Tessen is managed

Default value: `true`

##### `tessen_ensure`

Data type: `Enum['present','absent']`

Determine if Tessen is opt-in (present) or opt-out (absent)

Default value: 'present'

##### `ad_auths`

Data type: `Hash`

Hash of sensu_ad_auth resources

Default value: {}

##### `assets`

Data type: `Hash`

Hash of sensu_asset resources

Default value: {}

##### `bonsai_assets`

Data type: `Hash`

Hash of sensu_bonsai_asset resources

Default value: {}

##### `checks`

Data type: `Hash`

Hash of sensu_check resources

Default value: {}

##### `cluster_members`

Data type: `Hash`

Hash of sensu_cluster_member resources

Default value: {}

##### `cluster_role_bindings`

Data type: `Hash`

Hash of sensu_cluster_role_binding resources

Default value: {}

##### `cluster_roles`

Data type: `Hash`

Hash of sensu_cluster_role resources

Default value: {}

##### `configs`

Data type: `Hash`

Hash of sensu_config resources

Default value: {}

##### `entities`

Data type: `Hash`

Hash of sensu_entity resources

Default value: {}

##### `etcd_replicators`

Data type: `Hash`

Hash of sensu_etcd_replicator resources

Default value: {}

##### `events`

Data type: `Hash`

Hash of sensu_event resources

Default value: {}

##### `filters`

Data type: `Hash`

Hash of sensu_filter resources

Default value: {}

##### `handlers`

Data type: `Hash`

Hash of sensu_handler resources

Default value: {}

##### `hooks`

Data type: `Hash`

Hash of sensu_hook resources

Default value: {}

##### `ldap_auths`

Data type: `Hash`

Hash of sensu_ldap_auth resources

Default value: {}

##### `mutators`

Data type: `Hash`

Hash of sensu_mutator resources

Default value: {}

##### `namespaces`

Data type: `Hash`

Hash of sensu_namespace resources

Default value: {}

##### `oidc_auths`

Data type: `Hash`

Hash of sensu_oidc_auth resources

Default value: {}

##### `role_bindings`

Data type: `Hash`

Hash of sensu_role_binding resources

Default value: {}

##### `roles`

Data type: `Hash`

Hash of sensu_role resources

Default value: {}

##### `silencings`

Data type: `Hash`

Hash of sensu_silenced resources

Default value: {}

##### `users`

Data type: `Hash`

Hash of sensu_user resources

Default value: {}

##### `sensuctl_chunk_size`

Data type: `Optional[Integer]`

Chunk size to use when listing sensuctl resources

Default value: `undef`

##### `datastore`

Data type: `Optional[Enum['postgresql']]`

Datastore to configure for sensu events

Default value: `undef`

##### `datastore_ensure`

Data type: `Enum['present','absent']`

The datastore ensure property. If set to `absent` all
datastore parameters must still be defined.

Default value: 'present'

##### `manage_postgresql_db`

Data type: `Boolean`

Boolean that sets of postgresql database should be managed

Default value: `true`

##### `postgresql_name`

Data type: `String`

Name of PostgresConfig that is configured with sensuctl

Default value: 'postgresql'

##### `postgresql_user`

Data type: `String`

The PostgreSQL database user

Default value: 'sensu'

##### `postgresql_password`

Data type: `String`

The PostgreSQL database password

Default value: 'changeme'

##### `postgresql_host`

Data type: `Stdlib::Host`

The PostgreSQL host

Default value: 'localhost'

##### `postgresql_port`

Data type: `Stdlib::Port`

The PostgreSQL port

Default value: 5432

##### `postgresql_dbname`

Data type: `String`

The name of the PostgreSQL database

Default value: 'sensu'

##### `postgresql_pool_size`

Data type: `Integer`

The PostgreSQL pool size

Default value: 20

### sensu::plugins

Class to manage the Sensu plugins.

#### Examples

##### 

```puppet
class { 'sensu::plugins':
  plugins    => ['disk-checks'],
  extensions => ['graphite'],
}
```

##### 

```puppet
class { 'sensu::plugins':
  plugins    => {
    'disk-checks' => { 'version' => 'latest' },
  },
  extensions => {
    'graphite' => { 'version' => 'latest' },
  },
}
```

#### Parameters

The following parameters are available in the `sensu::plugins` class.

##### `manage_repo`

Data type: `Optional[Boolean]`

Determines if plugin repo should be managed.
Defaults to value for `sensu::manage_repo`.

Default value: `undef`

##### `package_ensure`

Data type: `String`

Ensure property for sensu plugins package.

Default value: 'installed'

##### `package_name`

Data type: `String`

Name of the Sensu plugins ruby package.

Default value: 'sensu-plugins-ruby'

##### `dependencies`

Data type: `Array`

Package dependencies needed to install plugins and extensions.
Default is OS dependent.

Default value: []

##### `gem_dependencies`

Data type: `Array`

Gem dependencies.

Default value: []

##### `plugins`

Data type: `Variant[Array, Hash]`

Plugins to install

Default value: []

##### `extensions`

Data type: `Variant[Array, Hash]`

Extensions to install

Default value: []

## Resource types

### sensu_ad_auth

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensu_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `Exec[sensu-add-license]`

#### Examples

##### Add an Active Directory auth

```puppet
sensu_ad_auth { 'ad':
  ensure              => 'present',
  servers             => [
    {
      'host' => '127.0.0.1',
      'port' => 636,
    },
  ],
  server_binding      => {
    '127.0.0.1' => {
      'user_dn' => 'cn=binder,dc=acme,dc=org',
      'password' => 'P@ssw0rd!'
    }
  },
  server_group_search => {
    '127.0.0.1' => {
      'base_dn' => 'dc=acme,dc=org',
    }
  },
  server_user_search  => {
    '127.0.0.1' => {
      'base_dn' => 'dc=acme,dc=org',
    }
  },
}
```

#### Properties

The following properties are available in the `sensu_ad_auth` type.

##### `ensure`

Valid values: present, absent

The basic property that the resource should be in.

Default value: present

##### `servers`

AD servers as Array of Hashes

Keys:
* host: required
* port: required
* insecure: default is `false`
* security: default is `tls`
* trusted_ca_file: default is `""`
* client_cert_file: default is `""`
* client_key_file: default is `""`
* default_upn_domain: default is `""`
* include_nested_groups: Boolean

##### `server_binding`

AD server bindings

##### `server_group_search`

Search configuration for groups.
Keys:
* base_dn: required
* attribute: default is `member`
* name_attribute: default is `cn`
* object_class: default is `group`

##### `server_user_search`

Search configuration for users.
Keys:
* base_dn: required
* attribute: default is `sAMAccountName`
* name_attribute: default is `displayName`
* object_class: default is `person`

##### `groups_prefix`

The prefix added to all AD groups.

##### `username_prefix`

The prefix added to all AD usernames.

#### Parameters

The following parameters are available in the `sensu_ad_auth` type.

##### `name`

namevar

The name of the AD auth.

### sensu_api_validator

Verify that a connection can be successfully established between a node
and the sensu-backend server.  Its primary use is as a precondition to
prevent configuration changes from being applied if the sensu_backend
server cannot be reached, but it could potentially be used for other
purposes such as monitoring.

#### Examples

##### Verify API connectivity to localhost:8080

```puppet
sensu_api_validator { 'sensu':
  sensu_api_server => 'localhost',
  sensu_api_ort    => 8080,
}
```

#### Properties

The following properties are available in the `sensu_api_validator` type.

##### `ensure`

Valid values: present, absent

The basic property that the resource should be in.

Default value: present

#### Parameters

The following parameters are available in the `sensu_api_validator` type.

##### `name`

namevar

An arbitrary name used as the identity of the resource.

##### `sensu_api_server`

The DNS name or IP address of the server where sensu_api should be running.

Default value: localhost

##### `sensu_api_port`

The port that the sensu_api server should be listening on.

Default value: 8080

##### `use_ssl`

Whether the connection will be attemped using https

Default value: `false`

##### `test_url`

URL to use for testing if the Sensu backend is up

Default value: /version

##### `timeout`

The max number of seconds that the validator should wait before giving up and deciding that sensu_api is not running; defaults to 15 seconds.

Default value: 30

### sensu_asset

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensu_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `sensu_namespace` - Puppet will autorequire `sensu_namespace` resource defined in `namespace` property.

#### Examples

##### Create an asset with multiple builds

```puppet
sensu_asset { 'test':
  ensure => 'present',
  builds => [
    {
      "url" => "https://assets.bonsai.sensu.io/981307deb10ebf1f1433a80da5504c3c53d5c44f/sensu-go-cpu-check_0.0.3_linux_amd64.tar.gz",
      "sha512" => "487ab34b37da8ce76d2657b62d37b35fbbb240c3546dd463fa0c37dc58a72b786ef0ca396a0a12c8d006ac7fa21923e0e9ae63419a4d56aec41fccb574c1a5d3",
      "filters" => [
        "entity.system.os == 'linux'",
        "entity.system.arch == 'amd64'"
      ],
      "headers" => {
        "Authorization" => "Bearer $TOKEN",
        "X-Forwarded-For" => "client1, proxy1, proxy2",
      }
    },
    {
      "url" => "https://assets.bonsai.sensu.io/981307deb10ebf1f1433a80da5504c3c53d5c44f/sensu-go-cpu-check_0.0.3_linux_armv7.tar.gz",
      "sha512" => "70df8b7e9aa36cf942b972e1781af04815fa560441fcdea1d1538374066a4603fc5566737bfd6c7ffa18314edb858a9f93330a57d430deeb7fd6f75670a8c68b",
      "filters" => [
        "entity.system.os == 'linux'",
        "entity.system.arch == 'arm'",
        "entity.system.arm_version == 7"
      ],
      "headers" => {
        "Authorization" => "Bearer $TOKEN",
        "X-Forwarded-For" => "client1, proxy1, proxy2",
      }
    },
    {
      "url" => "https://assets.bonsai.sensu.io/981307deb10ebf1f1433a80da5504c3c53d5c44f/sensu-go-cpu-check_0.0.3_windows_amd64.tar.gz",
      "sha512" => "10d6411e5c8bd61349897cf8868087189e9ba59c3c206257e1ebc1300706539cf37524ac976d0ed9c8099bdddc50efadacf4f3c89b04a1a8bf5db581f19c157f",
      "filters" => [
        "entity.system.os == 'windows'",
        "entity.system.arch == 'amd64'"
      ],
      "headers" => {
        "Authorization" => "Bearer $TOKEN",
        "X-Forwarded-For" => "client1, proxy1, proxy2",
      }
    }
  ],
}
```

#### Properties

The following properties are available in the `sensu_asset` type.

##### `ensure`

Valid values: present, absent

The basic property that the resource should be in.

Default value: present

##### `url`

The URL location of the asset.

##### `sha512`

The checksum of the asset

##### `filters`

Valid values: /.*/, absent

A set of filters used by the agent to determine of the asset should be installed.

##### `builds`

A list of asset builds used to define multiple artifacts which provide the named asset.

Keys:
* url: required
* sha512: required
* filters: optional Array
* headers: optional Hash

##### `headers`

HTTP headers to appy to asset retrieval requests.

##### `namespace`

The Sensu RBAC namespace that this asset belongs to.

Default value: default

##### `labels`

Custom attributes to include with event data, which can be queried like regular attributes.

##### `annotations`

Arbitrary, non-identifying metadata to include with event data.

#### Parameters

The following parameters are available in the `sensu_asset` type.

##### `name`

namevar

The name of the asset.
The name supports composite names that can define the namespace.
An example composite name to define resource named `test` in namespace `dev`: `test in dev`

##### `resource_name`

The name of the asset.

##### `bonsai`

Valid values: `true`, `false`

Private property used by sensu_bonsai_asset type

### sensu_bonsai_asset

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensu_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `sensu_namespace` - Puppet will autorequire `sensu_namespace` resource defined in `namespace` property.

#### Examples

##### Install a bonsai asset

```puppet
sensu_bonsai_asset { 'sensu/sensu-pagerduty-handler':
  ensure  => 'present',
}
```

##### Install specific version of a bonsai asset

```puppet
sensu_bonsai_asset { 'sensu/sensu-pagerduty-handler':
  ensure  => 'present',
  version => '1.2.0',
}
```

##### Install latest version of a bonsai asset

```puppet
sensu_bonsai_asset { 'sensu/sensu-pagerduty-handler':
  ensure  => 'present',
  version => 'latest',
}
```

#### Properties

The following properties are available in the `sensu_bonsai_asset` type.

##### `ensure`

Valid values: present, absent

Bonsai asset state for Sensu Go asset

Default value: present

##### `version`

Valid values: latest, /[0-9\.]+/

Specific version to install, or latest

#### Parameters

The following parameters are available in the `sensu_bonsai_asset` type.

##### `name`

namevar

Bonsai asset name

##### `bonsai_namespace`

Bonsai asset namespace

##### `bonsai_name`

Bonsai asset name

##### `namespace`

The Sensu RBAC namespace that this asset belongs to.

Default value: default

##### `rename`

Name for Sensu Go asset

### sensu_check

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensu_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `sensu_namespace` - Puppet will autorequire `sensu_namespace` resource defined in `namespace` property.
* `sensu_handler` - Puppet will autorequie `sensu_handler` resources defined in `handlers` property.
* `sensu_asset` - Puppet will autorequire `sensu_asset` resources defined in `runtime_assets` property.
* `sensu_hook` - Puppet will autorequire `sensu_hook` resources defined in `check_hooks` property.

#### Examples

##### Create a check

```puppet
sensu_check { 'test':
  ensure        => 'present',
  command       => 'check-http.rb',
  subscriptions => ['demo'],
  handlers      => ['email'],
  interval      => 60,
}
```

##### Create a check that has a hook

```puppet
sensu_check { 'test':
  ensure        => 'present',
  command       => 'check-cpu.sh -w 75 -c 90',
  subscriptions => ['linux'],
  check_hooks   => [
    { 'critical' => ['ps'] },
    { 'warning'  => ['ps'] },
  ],
  interval      => 60,
}
```

##### Create a check with namespace `dev` in the name

```puppet
sensu_check { 'test in dev':
  ensure        => 'present',
  command       => 'check-http.rb',
  subscriptions => ['demo'],
  handlers      => ['email'],
  interval      => 60,
}
```

#### Properties

The following properties are available in the `sensu_check` type.

##### `ensure`

Valid values: present, absent

The basic property that the resource should be in.

Default value: present

##### `command`

The check command to be executed.

##### `subscriptions`

An array of Sensu entity subscriptions that check requests will be sent to.

##### `handlers`

An array of Sensu event handlers (names) to use for events created by the check.

##### `interval`

Valid values: /^[0-9]+$/, absent

The frequency in seconds the check is executed.

##### `cron`

Valid values: /.*/, absent

When the check should be executed, using the Cron syntax.

##### `publish`

Valid values: `true`, `false`

If check requests are published for the check.

Default value: true

##### `timeout`

Valid values: /^[0-9]+$/, absent

The check execution duration timeout in seconds (hard stop).

##### `ttl`

Valid values: /^[0-9]+$/, absent

The time to live (TTL) in seconds until check results are considered stale.

##### `stdin`

Valid values: `true`, `false`

If the Sensu agent writes JSON serialized Sensu entity and check data to the command process' STDIN

Default value: false

##### `low_flap_threshold`

Valid values: /^[0-9]+$/, absent

The flap detection low threshold (% state change) for the check

##### `high_flap_threshold`

Valid values: /^[0-9]+$/, absent

The flap detection high threshold (% state change) for the check

##### `runtime_assets`

Valid values: /.*/, absent

An array of Sensu assets (names), required at runtime for the execution of the command

##### `check_hooks`

An array of check response types with respective arrays of Sensu hook names.

##### `proxy_entity_name`

Valid values: /^[\w\.\-]+$/, absent

The entity name, used to create a proxy entity for an external resource (i.e., a network switch).

##### `round_robin`

Valid values: `true`, `false`

If the check should be executed on a single entity within a subscription in a round-robin fashion.

##### `proxy_requests_entity_attributes`

Sensu entity attributes to match entities in the registry, using Sensu Query Expressions

##### `proxy_requests_splay`

Valid values: `true`, `false`

If proxy check requests should be splayed

##### `proxy_requests_splay_coverage`

The splay coverage percentage use for proxy check request splay calculation.

##### `silenced`

Valid values: `true`, `false`

If the event is to be silenced.

##### `env_vars`

Valid values: /.*/, absent

An array of environment variables to use with command execution.

##### `output_metric_format`

Valid values: nagios_perfdata, graphite_plaintext, influxdb_line, opentsdb_line, absent

The metric format generated by the check command.

##### `output_metric_handlers`

Valid values: /.*/, absent

An array of Sensu handlers to use for events created by the check.

##### `max_output_size`

Maximum size, in bytes, of stored check outputs.

##### `discard_output`

Valid values: `true`, `false`

Discard check output after extracting metrics.

##### `namespace`

The Sensu RBAC namespace that this check belongs to.

Default value: default

##### `labels`

Custom attributes to include with event data, which can be queried like regular attributes.

##### `annotations`

Arbitrary, non-identifying metadata to include with event data.

#### Parameters

The following parameters are available in the `sensu_check` type.

##### `name`

namevar

The name of the check.
The name supports composite names that can define the namespace.
An example composite name to define resource named `test` in namespace `dev`: `test in dev`

##### `resource_name`

The name of the check.

### sensu_cluster_member

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensu_configure[puppet]`
* `Sensu_api_validator[sensu]`

#### Examples

##### Add a cluster member

```puppet
sensu_cluster_member { 'backend2':
  ensure    => 'present',
  peer_urls => ['http://192.168.52.12:2380'],
}
```

#### Properties

The following properties are available in the `sensu_cluster_member` type.

##### `ensure`

Valid values: present, absent

The basic property that the resource should be in.

Default value: present

##### `peer_urls`

Array of cluster peer URLs

#### Parameters

The following parameters are available in the `sensu_cluster_member` type.

##### `name`

namevar

The name of the cluster member.

##### `id`

Cluster member ID - read-only

### sensu_cluster_role

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensu_configure[puppet]`
* `Sensu_api_validator[sensu]`

#### Examples

##### Add a cluster role

```puppet
sensu_cluster_role { 'test':
  ensure => 'present',
  rules  => [{'verbs' => ['get','list'], 'resources' => ['checks'], 'resource_names' => ['']}],
}
```

#### Properties

The following properties are available in the `sensu_cluster_role` type.

##### `ensure`

Valid values: present, absent

The basic property that the resource should be in.

Default value: present

##### `rules`

The rulesets that a role applies.

#### Parameters

The following parameters are available in the `sensu_cluster_role` type.

##### `name`

namevar

The name of the role.

### sensu_cluster_role_binding

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensu_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `sensu_cluster_role` - Puppet will autorequire `sensu_cluster_role` resource defined in `role_ref` property.
* `sensu_user` - Puppet will autorequire `sensu_user` resources based on users and groups defined for the `subjects` property.

#### Examples

##### Add a cluster role binding

```puppet
sensu_cluster_role_binding { 'test':
  ensure   => 'present',
  role_ref => {'type' => 'ClusterRole', 'name' => 'test-role'},
  subjects => [
    { 'type' => 'User', 'name' => 'test-user' }
  ],
}
```

##### Add a cluster role binding for a Role

```puppet
sensu_cluster_role_binding { 'test':
  ensure   => 'present',
  role_ref => {'type' => 'Role', 'name' => 'test-role'},
  subjects => [
    { 'type' => 'User', 'name' => 'test-user' }
  ],
}
```

#### Properties

The following properties are available in the `sensu_cluster_role_binding` type.

##### `ensure`

Valid values: present, absent

The basic property that the resource should be in.

Default value: present

##### `role_ref`

References a role in the current namespace or a cluster role.

##### `subjects`

The users or groups being assigned.

#### Parameters

The following parameters are available in the `sensu_cluster_role_binding` type.

##### `name`

namevar

The name of the role binding.

### sensu_config

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensu_configure[puppet]`
* `Sensu_api_validator[sensu]`

#### Examples

##### Manage a config

```puppet
sensu_config { 'format':
  value => 'json',
}
```

#### Properties

The following properties are available in the `sensu_config` type.

##### `ensure`

Valid values: present, absent

The basic property that the resource should be in.

Default value: present

##### `value`

The value of the config.

#### Parameters

The following parameters are available in the `sensu_config` type.

##### `name`

namevar

The name of the config.

### sensu_configure

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensu_api_validator[sensu]`
* `file` - Puppet will autorequire `file` resources defined in `trusted_ca_file` property.

#### Properties

The following properties are available in the `sensu_configure` type.

##### `ensure`

Valid values: present, absent

The basic property that the resource should be in.

Default value: present

##### `url`

sensu-backend URL

##### `trusted_ca_file`

Path to trusted CA

Default value: /etc/sensu/ssl/ca.crt

#### Parameters

The following parameters are available in the `sensu_configure` type.

##### `name`

namevar

The name of the resource.

##### `username`

Username to use with sensuctl configure

##### `password`

Password to use with sensuctl configure

##### `bootstrap_password`

Password to use when bootstrapping sensuctl

Default value: P@ssw0rd!

### sensu_entity

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensu_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `sensu_namespace` - Puppet will autorequire `sensu_namespace` resource defined in `namespace` property.
* `sensu_handler` - Puppet will autorequie `sensu_handler` resource defined in `deregistration_handler` property.

#### Examples

##### Create an entity

```puppet
sensu_entity { 'test':
  ensure       => 'present',
  entity_class => 'proxy',
}
```

##### Create an entity with namespace `dev` in the name

```puppet
sensu_entity { 'test in dev':
  ensure       => 'present',
  entity_class => 'proxy',
}
```

#### Properties

The following properties are available in the `sensu_entity` type.

##### `ensure`

Valid values: present, absent

The basic property that the resource should be in.

Default value: present

##### `entity_class`

The entity type

##### `subscriptions`

A list of subscription names for the entity

##### `system`

System information about the entity, such as operating system and platform.

##### `last_seen`

Timestamp the entity was last seen, in epoch time.

##### `deregister`

Valid values: `true`, `false`

If the entity should be removed when it stops sending keepalive messages.

Default value: false

##### `deregistration_handler`

The name of the handler to be called when an entity is deregistered.

##### `redact`

List of items to redact from log messages.

##### `namespace`

The Sensu RBAC namespace that this entity belongs to.

Default value: default

##### `labels`

Custom attributes to include with event data, which can be queried like regular attributes.

##### `annotations`

Arbitrary, non-identifying metadata to include with event data.

#### Parameters

The following parameters are available in the `sensu_entity` type.

##### `name`

namevar

The name of the entity.
The name supports composite names that can define the namespace.
An example composite name to define resource named `test` in namespace `dev`: `test in dev`

##### `resource_name`

The name of the entity.

### sensu_etcd_replicator

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensu_configure[puppet]`
* `Sensu_api_validator[sensu]`

#### Examples

##### Create an Etcd Replicator

```puppet
sensu_etcd_replicator { 'role_replicator':
  ensure                       => 'present',
  ca_cert                      => '/path/to/ssl/trusted-certificate-authorities.pem',
  cert                         => '/path/to/ssl/cert.pem',
  key                          => '/path/to/ssl/key.pem',
  insecure                     => false,
  url                          => 'http://127.0.0.1:2379',
  api_version                  => 'core/v2',
  resource_name                => 'Role',
  replication_interval_seconds => 30,
}
```

#### Properties

The following properties are available in the `sensu_etcd_replicator` type.

##### `ensure`

Valid values: present, absent

The basic property that the resource should be in.

Default value: present

##### `ca_cert`

Path to an the PEM-format CA certificate to use for TLS client authentication.

##### `cert`

Path to the PEM-format certificate to use for TLS client authentication.

##### `key`

Path to the PEM-format key file associated with the cert to use for TLS client authentication.

##### `insecure`

Valid values: `true`, `false`

true to disable transport security.

Default value: false

##### `url`

Destination cluster URL. If specifying more than one, use a comma to separate.

##### `api_version`

Sensu API version of the resource to replicate

Default value: core/v2

##### `resource_name`

Name of the resource to replicate

##### `namespace`

Namespace to constrain replication to. If you do not include namespace, all namespaces for a given resource are replicated.

##### `replication_interval_seconds`

Valid values: /^[0-9]+$/, absent

The interval at which the resource will be replicated

Default value: 30

#### Parameters

The following parameters are available in the `sensu_etcd_replicator` type.

##### `name`

namevar

The name of the Etcd Replicator.

### sensu_event

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensu_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `sensu_namespace` - Puppet will autorequire `sensu_namespace` resource defined in `namespace` property.

#### Examples

##### Resolve an event

```puppet
sensu_event { 'test for sensu-agent':
  ensure => 'resolve'
}
```

##### Delete an event

```puppet
sensu_event { 'test for sensu-agent':
  ensure => 'absent'
}
```

#### Properties

The following properties are available in the `sensu_event` type.

##### `ensure`

Valid values: present, resolve, absent, delete

Aliases: "delete"=>"absent"

The basic property that the resource should be in.

#### Parameters

The following parameters are available in the `sensu_event` type.

##### `name`

namevar

Event name. Can take form of '<check> for <entity>'.

##### `entity`

The name of the entity the event should match

##### `check`

The name of the check the event should match

##### `namespace`

The Sensu RBAC namespace that this event belongs to.

Default value: default

### sensu_filter

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensu_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `sensu_namespace` - Puppet will autorequire `sensu_namespace` resource defined in `namespace` property.
* `sensu_asset` - Puppet will autorequire `sensu_asset` resources defined in `runtime_assets` property.

#### Examples

##### Create a filter

```puppet
sensu_filter { 'test':
  ensure      => 'present',
  action      => 'allow',
  expressions => ["event.entity.labels.environment == 'production'"],
}
```

##### Create a filter with namespace `dev` in the name

```puppet
sensu_filter { 'test in dev':
  ensure      => 'present',
  action      => 'allow',
  expressions => ["event.entity.labels.environment == 'production'"],
}
```

#### Properties

The following properties are available in the `sensu_filter` type.

##### `ensure`

Valid values: present, absent

The basic property that the resource should be in.

Default value: present

##### `action`

Valid values: allow, deny

Action to take with the event if the filter expressions match.

##### `expressions`

Filter expressions to be compared with event data.

##### `runtime_assets`

Valid values: /.*/, absent

Assets to be applied to the filter’s execution context.

##### `namespace`

The Sensu RBAC namespace that this filter belongs to.

Default value: default

##### `labels`

Custom attributes to include with event data, which can be queried like regular attributes.

##### `annotations`

Arbitrary, non-identifying metadata to include with event data.

#### Parameters

The following parameters are available in the `sensu_filter` type.

##### `name`

namevar

The name of the filter.
The name supports composite names that can define the namespace.
An example composite name to define resource named `test` in namespace `dev`: `test in dev`

##### `resource_name`

The name of the filter.

### sensu_handler

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensu_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `sensu_namespace` - Puppet will autorequire `sensu_namespace` resource defined in `namespace` property.
* `sensu_filter` - Puppet will autorequire `sensu_filter` resources defined in `filters` property.
* `sensu_mutator` - Puppet will autorequire `sensu_mutator` resource defined for `mutator` property.
* `sensu_handler` - Puppet will autorequire `sensu_handler` resources defined for `handlers` property.
* `sensu_asset` - Puppet will autorequire `sensu_asset` resources defined in `runtime_assets` property.

#### Examples

##### Create a handler

```puppet
sensu_handler { 'test':
  ensure  => 'present',
  type    => 'pipe',
  command => 'notify.rb'
}
```

##### Create a handler with namespace `dev` in the name

```puppet
sensu_handler { 'test in dev':
  ensure  => 'present',
  type    => 'pipe',
  command => 'notify.rb'
}
```

#### Properties

The following properties are available in the `sensu_handler` type.

##### `ensure`

Valid values: present, absent

The basic property that the resource should be in.

Default value: present

##### `type`

Valid values: pipe, tcp, udp, set

The handler type.

##### `filters`

Valid values: /.*/, absent

An array of Sensu event filters (names) to use when filtering events for the handler.

##### `mutator`

Valid values: /.*/, absent

The Sensu event mutator (name) to use to mutate event data for the handler.

##### `timeout`

Valid values: /^[0-9]+$/, absent

The handler execution duration timeout in seconds (hard stop)

##### `command`

Valid values: /.*/, absent

The handler command to be executed.

##### `env_vars`

Valid values: /.*/, absent

An array of environment variables to use with command execution.

##### `socket_host`

The socket host address (IP or hostname) to connect to.

##### `socket_port`

The socket port to connect to.

##### `handlers`

Valid values: /.*/, absent

An array of Sensu event handlers (names) to use for events using the handler set.

##### `runtime_assets`

Valid values: /.*/, absent

An array of Sensu assets (names), required at runtime for the execution of the command

##### `namespace`

The Sensu RBAC namespace that this handler belongs to.

Default value: default

##### `labels`

Custom attributes to include with event data, which can be queried like regular attributes.

##### `annotations`

Arbitrary, non-identifying metadata to include with event data.

#### Parameters

The following parameters are available in the `sensu_handler` type.

##### `name`

namevar

The name of the handler.
The name supports composite names that can define the namespace.
An example composite name to define resource named `test` in namespace `dev`: `test in dev`

##### `resource_name`

The name of the handler.

### sensu_hook

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensu_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `sensu_namespace` - Puppet will autorequire `sensu_namespace` resource defined in `namespace` property.
* `sensu_asset` - Puppet will autorequire `sensu_asset` resources defined in `runtime_assets` property.

#### Examples

##### Create a hook

```puppet
sensu_hook { 'test':
  ensure  => 'present',
  command => 'ps aux',
}
```

##### Create a hook with namespace `dev` in the name

```puppet
sensu_hook { 'test in dev':
  ensure  => 'present',
  command => 'ps aux',
}
```

#### Properties

The following properties are available in the `sensu_hook` type.

##### `ensure`

Valid values: present, absent

The basic property that the resource should be in.

Default value: present

##### `command`

The hook command to be executed.

##### `timeout`

The hook execution duration timeout in seconds (hard stop)

Default value: 60

##### `stdin`

Valid values: `true`, `false`

If the Sensu agent writes JSON serialized Sensu entity and check data to the command process’ STDIN.

Default value: false

##### `runtime_assets`

Valid values: /.*/, absent

An array of Sensu assets (names), required at runtime for the execution of the command

##### `namespace`

The Sensu RBAC namespace that this hook belongs to.

Default value: default

##### `labels`

Custom attributes to include with event data, which can be queried like regular attributes.

##### `annotations`

Arbitrary, non-identifying metadata to include with event data.

#### Parameters

The following parameters are available in the `sensu_hook` type.

##### `name`

namevar

The name of the hook.
The name supports composite names that can define the namespace.
An example composite name to define resource named `test` in namespace `dev`: `test in dev`

##### `resource_name`

The name of the hook.

### sensu_ldap_auth

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensu_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `Exec[sensu-add-license]`

#### Examples

##### Add a LDAP auth

```puppet
sensu_ldap_auth { 'openldap':
  ensure              => 'present',
  servers             => [
    {
      'host' => '127.0.0.1',
      'port' => 389,
    },
  ],
  server_binding      => {
    '127.0.0.1' => {
      'user_dn' => 'cn=binder,dc=acme,dc=org',
      'password' => 'P@ssw0rd!'
    }
  },
  server_group_search => {
    '127.0.0.1' => {
      'base_dn' => 'dc=acme,dc=org',
    }
  },
  server_user_search  => {
    '127.0.0.1' => {
      'base_dn' => 'dc=acme,dc=org',
    }
  },
}
```

#### Properties

The following properties are available in the `sensu_ldap_auth` type.

##### `ensure`

Valid values: present, absent

The basic property that the resource should be in.

Default value: present

##### `servers`

LDAP servers as Array of Hashes

Keys:
* host: required
* port: required
* insecure: default is `false`
* security: default is `tls`
* trusted_ca_file: default is `""`
* client_cert_file: default is `""`
* client_key_file: default is `""`

##### `server_binding`

LDAP server bindings

##### `server_group_search`

Search configuration for groups.
Keys:
* base_dn: required
* attribute: default is `member`
* name_attribute: default is `cn`
* object_class: default is `groupOfNames`

##### `server_user_search`

Search configuration for users.
Keys:
* base_dn: required
* attribute: default is `uid`
* name_attribute: default is `cn`
* object_class: default is `person`

##### `groups_prefix`

The prefix added to all LDAP groups.

##### `username_prefix`

The prefix added to all LDAP usernames.

#### Parameters

The following parameters are available in the `sensu_ldap_auth` type.

##### `name`

namevar

The name of the LDAP auth.

### sensu_mutator

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensu_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `sensu_namespace` - Puppet will autorequire `sensu_namespace` resource defined in `namespace` property.
* `sensu_asset` - Puppet will autorequire `sensu_asset` resources defined in `runtime_assets` property.

#### Examples

##### Create a mutator

```puppet
sensu_mutator { 'example':
  ensure  => 'present',
  command => 'example-mutator.rb',
}
```

##### Create a mutator with namespace `dev` in the name

```puppet
sensu_mutator { 'example in dev':
  ensure  => 'present',
  command => 'example-mutator.rb',
}
```

#### Properties

The following properties are available in the `sensu_mutator` type.

##### `ensure`

Valid values: present, absent

The basic property that the resource should be in.

Default value: present

##### `command`

The mutator command to be executed.

##### `timeout`

Valid values: /^[0-9]+$/, absent

The mutator execution duration timeout in seconds (hard stop)

##### `runtime_assets`

Valid values: /.*/, absent

An array of Sensu assets (names), required at runtime for the execution of the command

##### `env_vars`

Valid values: /.*/, absent

An array of environment variables to use with command execution.

##### `namespace`

The Sensu RBAC namespace that this mutator belongs to.

Default value: default

##### `labels`

Custom attributes to include with event data, which can be queried like regular attributes.

##### `annotations`

Arbitrary, non-identifying metadata to include with event data.

#### Parameters

The following parameters are available in the `sensu_mutator` type.

##### `name`

namevar

The name of the mutator.
The name supports composite names that can define the namespace.
An example composite name to define resource named `test` in namespace `dev`: `test in dev`

##### `resource_name`

The name of the mutator.

### sensu_namespace

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensu_configure[puppet]`
* `Sensu_api_validator[sensu]`

#### Examples

##### Add an namespace

```puppet
sensu_namespace { 'test':
  ensure => 'present',
}
```

#### Properties

The following properties are available in the `sensu_namespace` type.

##### `ensure`

Valid values: present, absent

The basic property that the resource should be in.

Default value: present

#### Parameters

The following parameters are available in the `sensu_namespace` type.

##### `name`

namevar

The name of the namespace.

### sensu_oidc_auth

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensu_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `Exec[sensu-add-license]`

#### Examples

##### Add an Active Directory auth

```puppet
sensu_oidc_auth { 'oidc':
  ensure            => 'present',
  additional_scopes => ['email','groups'],
  client_id         => '0oa13ry4ypeDDBpxF357',
  client_secret     => 'DlArQRfND4BKBUyO0mE-TL2PWOVwyGjIO1fdk9gX',
  groups_claim      => 'groups',
  groups_prefix     => 'oidc:',
  redirect_uri      => 'https://sensu-backend.example.com:8080/api/enterprise/authentication/v2/oidc/callback',
  server            => 'https://idp.example.com',
  username_claim    => 'email',
  username_prefix   => 'oidc:'
}
```

#### Properties

The following properties are available in the `sensu_oidc_auth` type.

##### `ensure`

Valid values: present, absent

The basic property that the resource should be in.

Default value: present

##### `client_id`

The OIDC provider application "Client ID"

##### `client_secret`

The OIDC provider application "Client Secret"

##### `server`

The location of the OIDC server you wish to authenticate against.

##### `redirect_uri`

Redirect URL to provide to the OIDC provider.

##### `groups_claim`

The claim to use to form the associated RBAC groups.

##### `groups_prefix`

A prefix to use to form the final RBAC groups if required.

##### `username_claim`

The claim to use to form the final RBAC user name.

##### `username_prefix`

A prefix to use to form the final RBAC user name.

##### `additional_scopes`

Scopes to include in the claims

#### Parameters

The following parameters are available in the `sensu_oidc_auth` type.

##### `name`

namevar

The name of the AD auth.

### sensu_plugin

**Autorequires**:
* `Package[sensu-plugins-ruby]`

#### Examples

##### Install a sensu plugin

```puppet
sensu_plugin { 'disk-checks':
  ensure  => 'present',
}
```

##### Install specific version of a sensu plugin

```puppet
sensu_plugin { 'disk-checks':
  ensure  => 'present',
  version => '4.0.0',
}
```

##### Install latest version of a sensu plugin

```puppet
sensu_plugin { 'disk-checks':
  ensure  => 'present',
  version => 'latest',
}
```

#### Properties

The following properties are available in the `sensu_plugin` type.

##### `ensure`

Valid values: present, absent

The basic property that the resource should be in.

Default value: present

##### `version`

Valid values: latest, /[0-9\.]+/

Specific version to install, or latest

#### Parameters

The following parameters are available in the `sensu_plugin` type.

##### `name`

namevar

Plugin or extension name

##### `extension`

Valid values: `true`, `false`

Sets to install an extension instead of a plugin

Default value: `false`

##### `source`

Install Sensu plugins and extensions from a custom SOURCE

##### `clean`

Valid values: `true`, `false`

Clean up (remove) other installed versions of the plugin(s) and/or extension(s)

Default value: `true`

##### `proxy`

Install Sensu plugins and extensions via a PROXY URL

### sensu_postgres_config

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensu_configure[puppet]`
* `Sensu_api_validator[sensu]`

#### Examples

##### Create an PostgreSQL datastore

```puppet
sensu_postgres_config { 'puppet':
  ensure    => 'present',
  dsn       => 'postgresql://sensu:changeme@localhost:5432/sensu',
  pool_size => 20,
}
```

#### Properties

The following properties are available in the `sensu_postgres_config` type.

##### `ensure`

Valid values: present, absent

The basic property that the resource should be in.

Default value: present

##### `dsn`

Use the dsn attribute to specify the data source names as a URL or PostgreSQL connection string

##### `pool_size`

Valid values: /^[0-9]+$/

The maximum number of connections to hold in the PostgreSQL connection pool

#### Parameters

The following parameters are available in the `sensu_postgres_config` type.

##### `name`

namevar

The name of the postgres config

### sensu_resources

Metatype for sensu resources

#### Examples

##### Purge unmanaged sensu_check resources

```puppet
sensu_resources { 'sensu_check':
  purge => true,
}
```

#### Parameters

The following parameters are available in the `sensu_resources` type.

##### `name`

namevar

The name of the type to be managed.

##### `purge`

Valid values: `true`, `false`, yes, no

Whether to purge unmanaged sensu resources.  When set to `true`, this will
delete any resource that is not specified in your configuration and is not
autorequired by any managed resources.

Default value: `false`

### sensu_role

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensu_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `sensu_namespace` - Puppet will autorequire `sensu_namespace` resource defined in `namespace` property.

#### Examples

##### Add a role

```puppet
sensu_role { 'test':
  ensure => 'present',
  rules  => [{'verbs' => ['get','list'], 'resources' => ['checks'], 'resource_names' => ['']}],
}
```

##### Add a role with namespace `dev` in the name

```puppet
sensu_role { 'test in dev':
  ensure => 'present',
  rules  => [{'verbs' => ['get','list'], 'resources' => ['checks'], 'resource_names' => ['']}],
}
```

#### Properties

The following properties are available in the `sensu_role` type.

##### `ensure`

Valid values: present, absent

The basic property that the resource should be in.

Default value: present

##### `namespace`

Namespace the role is restricted to.

Default value: default

##### `rules`

The rulesets that a role applies.

#### Parameters

The following parameters are available in the `sensu_role` type.

##### `name`

namevar

The name of the role.
The name supports composite names that can define the namespace.
An example composite name to define resource named `test` in namespace `dev`: `test in dev`

##### `resource_name`

The name of the role.

### sensu_role_binding

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensu_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `sensu_role` - Puppet will autorequire `sensu_role` resource defined in `role_ref` property.
* `sensu_namespace` - Puppet will autorequire `sensu_namespace` resource defined in `namespace` property.
* `sensu_user` - Puppet will autorequire `sensu_user` resources based on users and groups defined for the `subjects` property.

#### Examples

##### Add a role binding

```puppet
sensu_role_binding { 'test':
  ensure   => 'present',
  role_ref => {'type' => 'Role', 'name' => 'test-role'},
  subjects => [
    { 'type' => 'User', 'name' => 'test-user' }
  ],
}
```

##### Add a role binding for a ClusterRole

```puppet
sensu_role_binding { 'test':
  ensure   => 'present',
  role_ref => {'type' => 'ClusterRole', 'name' => 'test-role'},
  subjects => [
    { 'type' => 'User', 'name' => 'test-user' }
  ],
}
```

##### Add a role binding with namespace `dev` in the name

```puppet
sensu_role_binding { 'test in dev':
  ensure   => 'present',
  role_ref => {'type' => 'Role', 'name' => 'test-role'},
  subjects => [
    { 'type' => 'User', 'name' => 'test-user' }
  ],
}
```

#### Properties

The following properties are available in the `sensu_role_binding` type.

##### `ensure`

Valid values: present, absent

The basic property that the resource should be in.

Default value: present

##### `namespace`

Namespace the role binding is restricted to.

Default value: default

##### `role_ref`

References a role in the current namespace or a cluster role.

##### `subjects`

The users or groups being assigned.

#### Parameters

The following parameters are available in the `sensu_role_binding` type.

##### `name`

namevar

The name of the binding.
The name supports composite names that can define the namespace.
An example composite name to define resource named `test` in namespace `dev`: `test in dev`

##### `resource_name`

The name of the role binding.

### sensu_silenced

The name of a `sensu_silenced` resource may not match the name returned by sensuctl.
The name from sensuctl will take the form of `subscription:check`.
If you wish to have a `sensu_silenced` resource name match sensuctl then define the name
using the `subscription:check` format and do not define `subscription` or `check` properties.

The `subscription` and `check` properties take precedence over value in the name if name takes the form `subscription:check`.

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensu_configure[puppet]`
* `Sensu_api_validator[sensu]`
* `sensu_namespace` - Puppet will autorequire `sensu_namespace` resource defined in `namespace` property.

#### Examples

##### Create a silencing for all checks with subscription entity:sensu_agent

```puppet
sensu_silenced { 'test':
  ensure       => 'present',
  subscription => 'entity:sensu_agent',
}
```

##### Define silencing using composite name where `subscription=entity:sensu_agent` and `check=*`.

```puppet
sensu_silenced { 'entity:sensu_agent:*':
  ensure => 'present',
}
```

##### Define silencing using composite name where `subscription=linux` and `check=check-http`.

```puppet
sensu_silenced { 'linux:check-http':
  ensure => 'present',
}
```

##### Define silencing where subscription is linux and check is check-http. The `subscription` property overrides the value from name.

```puppet
sensu_silenced { 'test:check-http':
  ensure       => 'present',
  subscription => 'linux',
}
```

##### Define silencing where subscription is linux and check is test. The `check` property overrides the value from name.

```puppet
sensu_silenced { 'linux:check-http':
  ensure => 'present',
  check  => 'test',
}
```

#### Properties

The following properties are available in the `sensu_silenced` type.

##### `ensure`

Valid values: present, absent

The basic property that the resource should be in.

Default value: present

##### `begin`

Time at which silence entry goes into effect, in epoch.

##### `expire`

Number of seconds until this entry should be deleted.

Default value: -1

##### `expire_on_resolve`

Valid values: `true`, `false`

If the entry should be deleted when a check begins return OK status (resolves).

Default value: false

##### `creator`

Valid values: /.*/, absent

Person/application/entity responsible for creating the entry.

##### `reason`

Valid values: /.*/, absent

Explanation for the creation of this entry.

##### `namespace`

The Sensu RBAC namespace that this silenced belongs to.

Default value: default

##### `labels`

Custom attributes to include with event data, which can be queried like regular attributes.

##### `annotations`

Arbitrary, non-identifying metadata to include with event data.

#### Parameters

The following parameters are available in the `sensu_silenced` type.

##### `name`

namevar

Silenced name

##### `check`

The name of the check the entry should match

##### `subscription`

The name of the subscription the entry should match

### sensu_user

**Autorequires**:
* `Package[sensu-go-cli]`
* `Service[sensu-backend]`
* `Sensu_configure[puppet]`
* `Sensu_api_validator[sensu]`

#### Examples

##### Create a user

```puppet
sensu_user { 'test':
  ensure   => 'present',
  password => 'supersecret',
  groups   => ['users'],
}
```

##### Change a user's password

```puppet
sensu_user { 'test'
  ensure       => 'present',
  password     => 'newpassword',
  old_password => 'supersecret',
  groups       => ['users'],
}
```

#### Properties

The following properties are available in the `sensu_user` type.

##### `ensure`

Valid values: present, absent

The basic property that the resource should be in.

Default value: present

##### `password`

The user's password.

##### `groups`

Groups to which the user belongs.

##### `disabled`

Valid values: `true`, `false`

The state of the user’s account.

Default value: false

#### Parameters

The following parameters are available in the `sensu_user` type.

##### `name`

namevar

The name of the user.

##### `old_password`

The user's old password, needed in order to change a user's password

##### `configure`

Valid values: `true`, `false`

Run sensuctl configure for this user

Default value: `false`

##### `configure_url`

URL to use with 'sensuctl configure'

Default value: http://127.0.0.1:8080

### sensuctl_config

Abstract type to configure other types

#### Parameters

The following parameters are available in the `sensuctl_config` type.

##### `name`

namevar

The name of the resource.

##### `chunk_size`

sensuctl chunk-size

## Data types

### Sensu::Backend_URL

Sensu Backend URL's require protocol of ws:// or wss://.
A port is also required.
There is logic in sensu::agent class to add the protocol so it's optional.

Alias of `Variant[Pattern[/^[^\s:]+:\d+$/], Pattern[/^ws:\/\/[^\s:]+:\d+$/], Pattern[/^wss:\/\/[^\s:]++:\d+$/]]`

## Tasks

### agent_event

Create a Sensu Go agent event via the agent API

**Supports noop?** false

#### Parameters

##### `name`

Data type: `String[1]`

The name of the event

##### `status`

Data type: `Integer`

The event status

##### `output`

Data type: `String[1]`

The event output

##### `ttl`

Data type: `Optional[Integer]`

The event TTL

##### `port`

Data type: `Optional[Integer]`

The agent API port, defaults to 3031

### apikey

Manage Sensu Go API keys

**Supports noop?** false

#### Parameters

##### `action`

Data type: `Enum[create,list,delete]`

The action to perform

##### `username`

Data type: `Optional[String[1]]`

The username for the API key. Required for action=create

##### `key`

Data type: `Optional[String[1]]`

The API key. Required for action=delete

### assets_outdated

Retreive outdated Sensu Go assets

**Supports noop?** false

#### Parameters

##### `namespace`

Data type: `Optional[String[1]]`

The namespace, defaults to all namespaces

### check_execute

Execute a Sensu Go check

**Supports noop?** false

#### Parameters

##### `check`

Data type: `String[1]`

The name of the check to execute

##### `subscription`

Data type: `Optional[String[1]]`

The subscription

##### `namespace`

Data type: `Optional[String[1]]`

The namespace, defaults to `default`

##### `reason`

Data type: `Optional[String[1]]`

Explanation for the creation of this entry.

### event

Manage Sensu Go events

**Supports noop?** false

#### Parameters

##### `action`

Data type: `Enum[resolve,delete]`

The action to perform

##### `entity`

Data type: `String[1]`

The entity for event

##### `check`

Data type: `String[1]`

The check for event

##### `namespace`

Data type: `Optional[String[1]]`

The namespace for event

### install_agent

Install Sensu Go agent

**Supports noop?** false

#### Parameters

##### `backend`

Data type: `String[1]`

The backend(s) to connect agent to

##### `subscription`

Data type: `String[1]`

The subscription(s) for the agent

##### `namespace`

Data type: `Optional[String[1]]`

The namespace for the agent, default is 'default'

##### `output`

Data type: `Optional[Boolean]`

Return output from commands

### install_agent_linux

Install Sensu Go agent on Linux

**Supports noop?** false

### install_agent_windows

Install Sensu Go agent on Windows

**Supports noop?** false

### silenced

Manage Sensu Go silencings

**Supports noop?** false

#### Parameters

##### `action`

Data type: `Enum[create,update,delete]`

The action to perform

##### `subscription`

Data type: `Optional[String[1]]`

The subscription to silence

##### `check`

Data type: `Optional[String[1]]`

The check to silence

##### `namespace`

Data type: `Optional[String[1]]`

The namespace for silenced resources

##### `begin`

Data type: `Optional[Integer]`

Time at which silence entry goes into effect, in epoch.

##### `expire`

Data type: `Optional[Integer]`

Number of seconds until this entry should be deleted.

##### `expire_on_resolve`

Data type: `Optional[Boolean]`

If the entry should be deleted when a check begins return OK status (resolves).

##### `creator`

Data type: `Optional[String]`

Person/application/entity responsible for creating the entry.

##### `reason`

Data type: `Optional[String]`

Explanation for the creation of this entry.

